searchNodes=[{"doc":"Implementation of JSONPointer. This module handles JSONPointers as an internal term representation and provides functions to manipulate the JSONPointer term and to use the representation to traverse or manipulate JSON data. See: https://www.rfc-editor.org/rfc/rfc6901 for the specification. Warning Do not rely on the private internal implementation of JSONPointer, it may change in the future.","ref":"JsonPointer.html","title":"JsonPointer","type":"module"},{"doc":"rolls back the JsonPointer to the parent of its most distant leaf. iex&gt; { :ok , ptr } = &quot;/foo/bar&quot; |&gt; JsonPointer . from_path |&gt; JsonPointer . backtrack iex&gt; JsonPointer . to_path ( ptr ) &quot;/foo&quot;","ref":"JsonPointer.html#backtrack/1","title":"JsonPointer.backtrack/1","type":"function"},{"doc":"like backtrack/1 , but raises if attempted to backtrack from the root.","ref":"JsonPointer.html#backtrack!/1","title":"JsonPointer.backtrack!/1","type":"function"},{"doc":"converts a path to a JsonPointer iex&gt; JsonPointer . from_path ( &quot;/&quot; ) # the root-only case [ ] iex&gt; JsonPointer . from_path ( &quot;/foo/bar&quot; ) [ &quot;foo&quot; , &quot;bar&quot; ] iex&gt; JsonPointer . from_path ( &quot;/foo~0bar/baz&quot; ) [ &quot;foo~bar&quot; , &quot;baz&quot; ] iex&gt; JsonPointer . from_path ( &quot;/currency/%E2%82%AC&quot; ) [ &quot;currency&quot; , &quot;€&quot; ]","ref":"JsonPointer.html#from_path/1","title":"JsonPointer.from_path/1","type":"function"},{"doc":"converts a URI (or a URI-string) to a JsonPointer. iex&gt; JsonPointer . from_uri ( &quot;#/foo/bar&quot; ) [ &quot;foo&quot; , &quot;bar&quot; ] iex&gt; JsonPointer . from_uri ( &quot;/foo/bar&quot; ) [ &quot;foo&quot; , &quot;bar&quot; ] iex&gt; JsonPointer . from_uri ( % URI { path : &quot;/foo/bar&quot; } ) [ &quot;foo&quot; , &quot;bar&quot; ] iex&gt; JsonPointer . from_uri ( % URI { fragment : &quot;/foo/bar&quot; , host : &quot;elixir-lang.org&quot; } ) [ &quot;foo&quot; , &quot;bar&quot; ]","ref":"JsonPointer.html#from_uri/1","title":"JsonPointer.from_uri/1","type":"function"},{"doc":"appends path to the JsonPointer. This may either be a t:String.t , a list of t:String.t . iex&gt; ptr = JsonPointer . from_path ( &quot;/foo/bar&quot; ) iex&gt; ptr |&gt; JsonPointer . join ( &quot;baz&quot; ) |&gt; JsonPointer . to_path &quot;/foo/bar/baz&quot; iex&gt; ptr |&gt; JsonPointer . join ( [ &quot;baz&quot; , &quot;quux&quot; ] ) |&gt; JsonPointer . to_path &quot;/foo/bar/baz/quux&quot;","ref":"JsonPointer.html#join/2","title":"JsonPointer.join/2","type":"function"},{"doc":"returns the last part of the pointer and the pointer without it. iex&gt; { rest , last } = &quot;/foo/bar&quot; |&gt; JsonPointer . from_path |&gt; JsonPointer . pop iex&gt; last &quot;bar&quot; iex&gt; JsonPointer . to_path ( rest ) &quot;/foo&quot; iex&gt; &quot;/&quot; |&gt; JsonPointer . from_path |&gt; JsonPointer . pop :error","ref":"JsonPointer.html#pop/1","title":"JsonPointer.pop/1","type":"function"},{"doc":"given some JSON data, resolves a the content pointed to by the JsonPointer. iex&gt; JsonPointer . resolve_json ( true , &quot;/&quot; ) { :ok , true } iex&gt; JsonPointer . resolve_json ( %{ &quot;foo~bar&quot; =&gt; &quot;baz&quot; } , &quot;/foo~0bar&quot; ) { :ok , &quot;baz&quot; } iex&gt; JsonPointer . resolve_json ( %{ &quot;€&quot; =&gt; [ &quot;quux&quot; , &quot;ren&quot; ] } , JsonPointer . from_path ( &quot;/%E2%82%AC/1&quot; ) ) { :ok , &quot;ren&quot; }","ref":"JsonPointer.html#resolve_json/2","title":"JsonPointer.resolve_json/2","type":"function"},{"doc":"given some JSON data, resolves a the content pointed to by the JsonPointer iex&gt; JsonPointer . resolve_json! ( true , &quot;/&quot; ) true iex&gt; JsonPointer . resolve_json! ( %{ &quot;foo~bar&quot; =&gt; &quot;baz&quot; } , &quot;/foo~0bar&quot; ) &quot;baz&quot; iex&gt; JsonPointer . resolve_json! ( %{ &quot;€&quot; =&gt; [ &quot;quux&quot; , &quot;ren&quot; ] } , JsonPointer . from_path ( &quot;/%E2%82%AC/1&quot; ) ) &quot;ren&quot;","ref":"JsonPointer.html#resolve_json!/2","title":"JsonPointer.resolve_json!/2","type":"function"},{"doc":"creates a JsonPointer to its path equivalent. iex&gt; JsonPointer . to_path ( [ &quot;foo&quot; , &quot;bar&quot; ] ) &quot;/foo/bar&quot; iex&gt; JsonPointer . to_path ( [ &quot;foo~bar&quot; , &quot;baz&quot; ] ) &quot;/foo~0bar/baz&quot; iex&gt; JsonPointer . to_path ( [ &quot;currency&quot; , &quot;€&quot; ] ) &quot;/currency/%E2%82%AC&quot;","ref":"JsonPointer.html#to_path/1","title":"JsonPointer.to_path/1","type":"function"},{"doc":"creates a URI.t/0 struct out of a JsonPointer. The JsonPointer is placed in the :fragment field of the URI. iex&gt; JsonPointer . to_uri ( [ &quot;foo&quot; , &quot;bar&quot; ] ) % URI { fragment : &quot;/foo/bar&quot; }","ref":"JsonPointer.html#to_uri/1","title":"JsonPointer.to_uri/1","type":"function"},{"doc":"updates nested JSON data at the location given by the JsonPointer. iex&gt; ptr = JsonPointer . from_path ( &quot;/foo/0&quot; ) iex&gt; JsonPointer . update_json! ( %{ &quot;foo&quot; =&gt; [ 1 , 2 ] } , ptr , &amp; ( &amp;1 + 1 ) ) %{ &quot;foo&quot; =&gt; [ 2 , 2 ] } iex&gt; JsonPointer . update_json! ( %{ &quot;foo&quot; =&gt; %{ &quot;0&quot; =&gt; 1 } } , ptr , &amp; ( &amp;1 + 1 ) ) %{ &quot;foo&quot; =&gt; %{ &quot;0&quot; =&gt; 2 } }","ref":"JsonPointer.html#update_json!/3","title":"JsonPointer.update_json!/3","type":"function"},{"doc":"","ref":"JsonPointer.html#t:json/0","title":"JsonPointer.json/0","type":"type"},{"doc":"","ref":"JsonPointer.html#t:t/0","title":"JsonPointer.t/0","type":"opaque"}]